==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderDigitalOceanBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderDigitalOceanBuilder extends ACMEIssuerDNS01ProviderDigitalOceanFluentImpl<ACMEIssuerDNS01ProviderDigitalOceanBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderDigitalOcean,ACMEIssuerDNS01ProviderDigitalOceanBuilder>{
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderDigitalOcean(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderDigitalOcean(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,ACMEIssuerDNS01ProviderDigitalOcean instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,ACMEIssuerDNS01ProviderDigitalOcean instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withTokenSecretRef(instance.getTokenSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOcean instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOcean instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withTokenSecretRef(instance.getTokenSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderDigitalOcean build() {
    ACMEIssuerDNS01ProviderDigitalOcean buildable = new ACMEIssuerDNS01ProviderDigitalOcean(fluent.getTokenSecretRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderDigitalOceanBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderDigitalOceanBuilder extends ACMEIssuerDNS01ProviderDigitalOceanFluent<ACMEIssuerDNS01ProviderDigitalOceanBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderDigitalOcean,ACMEIssuerDNS01ProviderDigitalOceanBuilder>{
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderDigitalOcean(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderDigitalOcean(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,ACMEIssuerDNS01ProviderDigitalOcean instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent,ACMEIssuerDNS01ProviderDigitalOcean instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderDigitalOcean());

    if (instance != null) {
      fluent.withTokenSecretRef(instance.getTokenSecretRef());
      fluent.withTokenSecretRef(instance.getTokenSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOcean instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanBuilder(ACMEIssuerDNS01ProviderDigitalOcean instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderDigitalOcean());

    if (instance != null) {
      this.withTokenSecretRef(instance.getTokenSecretRef());
      this.withTokenSecretRef(instance.getTokenSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderDigitalOceanFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderDigitalOcean build() {
    ACMEIssuerDNS01ProviderDigitalOcean buildable = new ACMEIssuerDNS01ProviderDigitalOcean(fluent.buildTokenSecretRef());
    return buildable;
  }
  
}
